#!/usr/bin/env Rscript       
source("~/git/LSHTM_analysis/config/gid.R")
source("~/git/LSHTM_analysis/scripts/plotting/get_plotting_dfs.R")

#===================================================================
corr_data = corr_data_extract(merged_df3, drug_name = drug)
#corr_data = corr_data_extract(merged_df2, drug_name = drug)

geneL_normal = c("pnca")
geneL_na_dy = c("gid")
geneL_na = c("rpob")
geneL_ppi2 = c("alr", "embb", "katg", "rpob")

core_cols <- c( "Log (OR)" , "MAF", "-Log (P)"
                    , "DUET", "FoldX"
                    , "DeepDDG", "Dynamut2"
                    , "ASA", "RSA", "RD", "KD"
                    , "Consurf", "SNAP2"
                    #, "mutation_info_labels"
)


if (tolower(gene)%in%geneL_normal){
  corrplot_cols = core_cols
}

if (tolower(gene)%in%geneL_na_dy){
  additional_cols = c("mCSM-NA"
                    , "Dynamut"
                    , "ENCoM-DDG"
                    , "ENCoM-DDS"
                    , "mCSM"
                    , "SDM"
                    , "DUET-d"
                    , "mutation_info_labels")
  corrplot_cols = c(core_cols, additional_cols)
}
if (tolower(gene)%in%geneL_na){
  additional_cols = c("mCSM-NA"
                    , "mutation_info_labels")
  corrplot_cols = c(core_cols, additional_cols)
  
}

if (tolower(gene)%in%geneL_ppi2){
  additional_cols = c("mCSM-PPI2"
                    , "mutation_info_labels")
  corrplot_cols = c(core_cols, additional_cols)
}

#========================================
# corrplot_cols <- c( "Log (OR)"
#                     , "MAF"
#                     , "-Log (P)"
#                     , "DUET"
#                     , "FoldX"
#                     , "DeepDDG"
#                     , "Dynamut2"
#                     , "mCSM-NA"
#                     , "Dynamut"
#                     , "ENCoM-DDG"
#                     , "ENCoM-DDS"
#                     , "mCSM"
#                     , "SDM"
#                     , "DUET-d"
#                     , "ASA"
#                     , "RSA"
#                     , "RD"
#                     , "KD"
#                     , "mutation_info_labels"
#                    )

corr_df <- corr_data[, corrplot_cols] # col order is according to corrplot_cols
head(corr_df); names(corr_df)

if ( all( corrplot_cols%in%names(corr_df) ) ){
  cat("\nPASS: Successfully selected"
      , length(corrplot_cols)
      , "columns for building correlation df")
} else {
  cat("\nFAIl: Something went wrong, numbers mismatch"
      , "\nExpected cols:", length(corrplot_cols)
      , "\nGot:", length(corr_df) )
}

#=====================================================
corrplot_df <- corr_df 

# stat_df = corrplot_df[, c("Log (OR)"
#                           , "MAF" 
#                           , "-Log (P)")]

plot_title <- "Correlation plots (stability)"

# Checkbox Names
# FIXME: select columns conditionally based on gene and grey out the ones that are not present!

cBCorrNames = c( "Odds Ratio"
                , "Allele Frequency"
                , "P-value"
                , "DUET"
                , "FoldX"
                , "DeepDDG"
                , "Dynamut2"
                , "ASA"
                , "RSA"
                , "RD"
                , "KD"
                , "Consurf"
                , "SNAP2"
                , "Nucleic Acid affinity"
                , "PPi2 affinity"
                
                #, "Dynamut"
                #, "ENCoM-Stability"
                #, "ENCoM-Flexibility"
                #, "mCSM"
                #, "SDM"
                #, "DUET-d"
)

# Checkbox Values (aka Column Names that are in corrplot_df)
cBCorrVals = c("Log (OR)"
              , "MAF"
              , "-Log (P)"
              , "DUET"
              , "FoldX"
              , "DeepDDG"
              , "Dynamut2"
              , "ASA"
              , "RSA"
              , "RD"
              , "KD"
              , "Consurf"
              , "SNAP2"
              , "mCSM-NA"
              , "mCSM-PPI2"
              # , "Dynamut"
              # , "ENCoM-DDG"
              # , "ENCoM-DDS"
              # , "mCSM"
              # , "SDM"
              # , "DUET-d"
 )

# Pre-selected checkboxes
cBCorrSelected = c("Log (OR)"
                   , "MAF"
                   , "-Log (P)")

#################
# Define UI
#################
u_corr <- fluidPage(
  
  headerPanel(plot_title),
  
  sidebarLayout(position = "left"
                , sidebarPanel(
                 checkboxGroupInput("variable", "Choose parameter:"
                                       , choiceNames  = cBCorrNames
                                       , choiceValues = cBCorrVals
                                       , selected     = cBCorrSelected
                  )
                  
                  # could be a fluid Row
                  , actionButton("add_col"     , "Render")
                  , actionButton("reset_graph" , "Reset Graphs")
                  , actionButton("select_all"  , "Select All")
                 
                  )
                
                # output/display
                , mainPanel(plotOutput(outputId = 'corrplot'
                                    , height = "1200px"
                                    , width  = "1500px")
#                           , height = "800px"
#                          , width  = "600px")
                          , textOutput("txt")
                )
  )
)

#################
# Define server
#################
s_corr <- shinyServer(function(input, output, session)
  
{
  
 #================
 # Initial render
 #================
  output$corrplot <- renderPlot({ 
  
    #---------------------
    # My correlation plot: initial plot
    #---------------------
    c_plot <- my_corr_pairs(corr_data_all = corrplot_df
                            , corr_cols = cBCorrSelected
                            , corr_method = "spearman"
                            , dot_size = 2
                            , ats = 1.5
                            , corr_lab_size = length(cBCorrNames)/length(cBCorrSelected) * 1.3
                            , corr_value_size = 1)
  })
  
 #====================
 # Interactive render
 #====================
  observeEvent(
    input$add_col, {
     
      # select cols for corrplot
      corr_cols_s <- c(input$variable)
    
      # render plot
      if (length(c(input$variable)) >= 2) {
      output$corrplot <- renderPlot({
        
        #---------------------
        # My correlation plot: user selects columns
        #---------------------
        c_plot <- my_corr_pairs(corr_data_all     = corrplot_df
                                , corr_cols       = corr_cols_s
                                , dot_size        = 2
                                , ats             = 1.5
                                , corr_lab_size   = length(cBCorrNames)/length(corr_cols_s) * 1.3
                                , corr_value_size = 1)

      })
      } else{ output$txt = renderText({"Argh, common! It's a correlation plot. Select >=2 vars!"})
        
      }
      
    })
  
 #==================================
 # Add button: Select All checkbox
 #==================================
  observeEvent(
    input$select_all,{

      updateCheckboxGroupInput(session, "variable", selected = cBCorrVals)
    }
)

 #================
 # Reset render
 #================
  observeEvent(
    input$reset_graph,{

      # reset checkboxes to default selection
      updateCheckboxGroupInput(session, "variable", selected = cBCorrSelected)


      # render plot
      output$corrplot <- renderPlot({

        #---------------------
        # My correlation plot: reset plot
        #---------------------
        c_plot <- my_corr_pairs(corr_data_all     = corrplot_df
                                , corr_cols       = cBCorrSelected
                                , dot_size        = 1.2
                                , ats             = 1.5
                                , corr_lab_size   = length(cBCorrNames)/length(cBCorrSelected) * 1.3
                                , corr_value_size = 1)
      })
    }
  )
}
)

shinyApp(ui = u_corr, server = s_corr)
