#!/usr/bin/env Rscript       

source("~/git/LSHTM_analysis/config/gid.R")
source("~/git/LSHTM_analysis/scripts/plotting/get_plotting_dfs.R")

#===================================================================
corr_data = corr_data_extract(merged_df3, drug_name = drug)
#corr_data = corr_data_extract(merged_df2, drug_name = drug)
#================================================================
#other globals
dist_colname <- LigDist_colname # ligand_distance (from globals)
dist_cutoff <- LigDist_cutoff # 10 (from globals)

cat("\nLigand distance cut off, colname:", dist_colname
    , "\nThe max distance", gene, "structure df" , ":", max_ang, "\u212b"
    , "\nThe min distance", gene, "structure df" , ":", min_ang, "\u212b")

########################################################################

#==========================================
#####################
# Correlation plot
#####################
colnames(corr_df_m3_f)

corrplot_cols_lig <- c( "Log (OR)"
                    ,  "MAF"
                    , "-Log (P)"
                    , "mCSM-lig"
                    , "mCSM-NA"
                    , "ASA"
                    , "RSA"
                    , "RD"
                    , "KD" 
                    , dist_colname
                   , "mutation_info_labels"
                   )

corr_df_lig <- corr_df_m3_f[, corrplot_cols_lig]
head(corr_df_lig)

corrplot_df_lig <- corr_df_lig 

# static df
# stat_df = corrplot_df_lig[, c("Log (OR)"
#                           , "MAF"
#                           , "-Log (P)"
#                           )]

plot_title_lig <- "Correlation plots (ligand affinity)"

# Checkbox Names
cCorrNames = c( "Odds Ratio"
             , "Allele Frequency"
             , "P-value"
             , "Ligand affinity"
             , "Nucleic Acid affinity"
             , "ASA"
             , "RSA"
             , "RD"
             , "KD" 
             , "Ligand Distance")

# Checkbox Values (aka Column Names that are in corrplot_df_lig)
cCorrVals = c("Log (OR)"
          , "MAF"
          , "-Log (P)"
          , "mCSM-lig"
          , "mCSM-NA"
          , "ASA"
          , "RSA"
          , "RD"
          , "KD" 
          , dist_colname)

# Pre-selected checkboxes
cCorrSelected = c("Log (OR)"
                   , "MAF"
                   , "-Log (P)")
#============
# Define UI 
#============
u_corr_lig<- fluidPage(
  headerPanel(plot_title_lig),
  sidebarLayout(position = "left"
                , sidebarPanel("Correlations: Filtered data data"
                  , numericInput(inputId = "lig_dist"
                                 , label = "Ligand distance cutoff"
                                 , value =  dist_cutoff # 10 default from globals
                                 , min = min_ang
                                 , max = max_ang)
                  , checkboxGroupInput("variable", "Choose parameter:"
                                       , choiceNames  = cCorrNames
                                       , choiceValues = cCorrVals
                                       , selected     = cCorrSelected
                  )
                  # could be a fluid Row
                  , actionButton("add_col"     , "Render")
                  , actionButton("reset_graph" , "Reset Graphs")
                  , actionButton("select_all"  , "Select All")
                  
                )
                
                # output/display
                , mainPanel(plotOutput(outputId = 'corrplot'
                                     , height = "1000px"
                                     , width  = "1200px")
                          # , height = "800px"
                          # , width  = "600px")
                , textOutput("txt")
                )
  )
)

#===============
# Define server
#===============
s_corr_lig <- shinyServer(function(input, output, session)
  
{ 

 #================
 # Initial render
 #================
  output$corrplot <- renderPlot({ 

    # get the user-specified lig_list
    dist_cutoff_ini = input$lig_dist
    
    # subset data for plot
    corrplot_df_lig_ini = corrplot_df_lig[corrplot_df_lig[[dist_colname]] < dist_cutoff_ini,]
    
    #---------------------
    # My correlation plot: initial plot
    #---------------------
    c_plot <- my_corr_pairs(
                            #corr_data_all = corrplot_df_lig
                            corr_data_all = corrplot_df_lig_ini
                            , corr_cols = cCorrSelected
                            , dot_size = 2
                            , ats = 1.5
                            , corr_lab_size = length(cCorrNames)/length(cCorrSelected) * 1.3
                            , corr_value_size = 1)
    
  })
  
 #====================
 # Interactive render
 #====================
  observeEvent(
    input$add_col, {
      
      # get the user-specified lig_list
      dist_cutoff_user = input$lig_dist

      # subset data for plot
      corrplot_df_lig_s = corrplot_df_lig[corrplot_df_lig[[dist_colname]] < dist_cutoff_user,]
      
      # select cols for corrplot
      corr_cols_s = c(input$variable)
    
      # render plot
      if (length(c(input$variable)) >= 2) {
      
        output$corrplot <- renderPlot({ 
          
          #---------------------
          # My correlation plot: user selects columns
          #---------------------
          c_plot <- my_corr_pairs(corr_data_all = corrplot_df_lig_s
                                  , corr_cols = corr_cols_s
                                  , dot_size = 1.6
                                  , ats = 1.5
                                  , corr_lab_size = length(cCorrNames)/length(corr_cols_s) * 1.3
                                  , corr_value_size = 1)
        })
      } else { output$txt = renderText({"Fuddu! It's a correlation plot. Select >=2 vars bewakoof!"})}
      
    })
    
 #==================================
 # Add button: Select All checkbox
 #==================================
  observeEvent(
    input$select_all,{

      updateCheckboxGroupInput(session, "variable", selected = cCorrVals)
    }
  )
  
 #================
 # Reset render
 #================
  observeEvent(
    input$reset_graph,{
      
      # reset checkboxes
      updateCheckboxGroupInput(session, "variable", selected = cCorrSelected)

      # render plot
      output$corrplot <- renderPlot({ 
        
        #---------------------
        # My correlation plot: reset plot
        #---------------------
        c_plot <- my_corr_pairs(corr_data_all = corrplot_df_lig
                                , corr_cols = cCorrSelected
                                , dot_size = 2
                                , ats = 1.5
                                , corr_lab_size = length(cCorrNames)/length(cCorrSelected) * 1.3
                                , corr_value_size = 1)
        
      })
    }
  )
}
)

shinyApp(ui = u_corr_lig, server = s_corr_lig)

